# rahhscidow, the Random Ahh Sci-Hub Downloader

For when you need to download a bunch of papers. Runs on `sci-hub`, but with a lot more grace and ease in error handling.

## how to use

1. Get DOIs of papers into .txt, preferably one per line
2. Run `rahhscidow`
3. Enjoy

## how to install
Do `pip install rahhscidow`
